/**
 * Copyright (c) 2008 Sonatype, Inc. All rights reserved.
 *
 * This program is licensed to you under the Apache License Version 2.0,
 * and you may not use this file except in compliance with the Apache License Version 2.0.
 * You may obtain a copy of the Apache License Version 2.0 at http://www.apache.org/licenses/LICENSE-2.0.
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the Apache License Version 2.0 is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the Apache License Version 2.0 for the specific language governing permissions and limitations there under.
 */
package org.sonatype.sisu.template.loader;

import java.io.File;
import java.io.InputStream;
import java.util.Enumeration;
import java.util.jar.JarEntry;
import java.util.jar.JarFile;

import org.apache.velocity.exception.ResourceNotFoundException;
import org.sonatype.sisu.template.TemplateLoader;

public class JarTemplateLoader implements TemplateLoader {

  private File jar;

  public JarTemplateLoader(File jar) {
    this.jar = jar;
  }

  public synchronized InputStream getResourceStream(String name) throws ResourceNotFoundException {

    if (!jar.exists()) {
      throw new ResourceNotFoundException("The specific JAR file does not exist: " + jar); 
    }
    
    try {
      JarFile jarFile = new JarFile(jar);     
      return jarFile.getInputStream(jarFile.getEntry(name));
    } catch (Exception e) {
      return null;
    }
  }
}
